var NAVTREEINDEX11 =
{
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,75],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,76],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,78],
"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[7,0,0,78],
"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[7,0,0,79],
"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,79],
"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,80],
"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,80],
"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,81],
"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,81],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,82],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[7,0,0,82],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[8,0,0,83],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[7,0,0,83],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[8,0,0,84],
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[7,0,0,84],
"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[7,0,0,85],
"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[8,0,0,85],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[8,0,0,86],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[7,0,0,86],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[8,0,0,87],
"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[7,0,0,87],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[8,0,0,88],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[7,0,0,88],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[8,0,0,89],
"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[7,0,0,89],
"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[8,0,0,90],
"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,90],
"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[7,0,0,91],
"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[8,0,0,91],
"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[7,0,0,92],
"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[8,0,0,92],
"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,93],
"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[8,0,0,93],
"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[7,0,0,94],
"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[8,0,0,94],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[8,0,0,95],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[7,0,0,95],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[8,0,0,96],
"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[7,0,0,96],
"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[8,0,0,97],
"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[7,0,0,97],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[8,0,0,98],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,98],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[8,0,0,99],
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[7,0,0,99],
"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[7,0,0,100],
"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[8,0,0,100],
"interfacefstarpu__mod_1_1fstarpu__data__release.html":[7,0,0,101],
"interfacefstarpu__mod_1_1fstarpu__data__release.html":[8,0,0,101],
"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[7,0,0,102],
"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[8,0,0,102],
"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[8,0,0,103],
"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[7,0,0,103],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[7,0,0,104],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[8,0,0,104],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[7,0,0,105],
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[8,0,0,105],
"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[7,0,0,106],
"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[8,0,0,106],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[7,0,0,107],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[8,0,0,107],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[7,0,0,108],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[8,0,0,108],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[7,0,0,109],
"interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[8,0,0,109],
"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[7,0,0,110],
"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[8,0,0,110],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[7,0,0,111],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[8,0,0,111],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[7,0,0,112],
"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[8,0,0,112],
"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[7,0,0,113],
"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[8,0,0,113],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[7,0,0,114],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[8,0,0,114],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[7,0,0,115],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[8,0,0,115],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[7,0,0,116],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[8,0,0,116],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[7,0,0,117],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[8,0,0,117],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[7,0,0,118],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[8,0,0,118],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[7,0,0,119],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[8,0,0,119],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[7,0,0,120],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[8,0,0,120],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[7,0,0,121],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[8,0,0,121],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[8,0,0,122],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[7,0,0,122],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[7,0,0,123],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[8,0,0,123],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[8,0,0,124],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[7,0,0,124],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[8,0,0,125],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[7,0,0,125],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[8,0,0,126],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[7,0,0,126],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[8,0,0,127],
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[7,0,0,127],
"interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[8,0,0,128],
"interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[7,0,0,128],
"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[8,0,0,129],
"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[7,0,0,129],
"interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[8,0,0,130],
"interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[7,0,0,130],
"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[8,0,0,131],
"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[7,0,0,131],
"interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[8,0,0,132],
"interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[7,0,0,132],
"interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[8,0,0,133],
"interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[7,0,0,133],
"interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[8,0,0,134],
"interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[7,0,0,134],
"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[8,0,0,135],
"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[7,0,0,135],
"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[7,0,0,136],
"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[8,0,0,136],
"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[7,0,0,137],
"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[8,0,0,137],
"interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[7,0,0,138],
"interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[8,0,0,138],
"interfacefstarpu__mod_1_1fstarpu__get__version.html":[7,0,0,139],
"interfacefstarpu__mod_1_1fstarpu__get__version.html":[8,0,0,139],
"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[7,0,0,140],
"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[8,0,0,140],
"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[7,0,0,141],
"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[8,0,0,141],
"interfacefstarpu__mod_1_1fstarpu__malloc.html":[8,0,0,142],
"interfacefstarpu__mod_1_1fstarpu__malloc.html":[7,0,0,142],
"interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[8,0,0,143],
"interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[7,0,0,143],
"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[8,0,0,144],
"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[7,0,0,144],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[8,0,0,145],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[7,0,0,145],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[8,0,0,146],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[7,0,0,146],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[7,0,0,147],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[8,0,0,147],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block__shadow.html":[7,0,0,148],
"interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block__shadow.html":[8,0,0,148],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ld.html":[7,0,0,149],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ld.html":[8,0,0,149],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html":[7,0,0,150],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html":[8,0,0,150],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[8,0,0,151],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[7,0,0,151],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[8,0,0,152],
"interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[7,0,0,152],
"interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[8,0,0,153],
"interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[7,0,0,153],
"interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html":[8,0,0,154],
"interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html":[7,0,0,154],
"interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html":[8,0,0,155],
"interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html":[7,0,0,155],
"interfacefstarpu__mod_1_1fstarpu__memory__pin.html":[8,0,0,156],
"interfacefstarpu__mod_1_1fstarpu__memory__pin.html":[7,0,0,156],
"interfacefstarpu__mod_1_1fstarpu__memory__unpin.html":[8,0,0,157],
"interfacefstarpu__mod_1_1fstarpu__memory__unpin.html":[7,0,0,157],
"interfacefstarpu__mod_1_1fstarpu__opencl__worker__get__count.html":[8,0,0,158],
"interfacefstarpu__mod_1_1fstarpu__opencl__worker__get__count.html":[7,0,0,158],
"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html":[8,0,0,159],
"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html":[7,0,0,159],
"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html":[8,0,0,160],
"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html":[7,0,0,160],
"interfacefstarpu__mod_1_1fstarpu__pause.html":[8,0,0,161],
"interfacefstarpu__mod_1_1fstarpu__pause.html":[7,0,0,161],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[7,0,0,162],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[8,0,0,162],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[7,0,0,163],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[8,0,0,163],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[7,0,0,164],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[8,0,0,164],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[7,0,0,165],
"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[8,0,0,165],
"interfacefstarpu__mod_1_1fstarpu__resume.html":[7,0,0,166],
"interfacefstarpu__mod_1_1fstarpu__resume.html":[8,0,0,166],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[7,0,0,167],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[8,0,0,167],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[7,0,0,168],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[8,0,0,168],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[7,0,0,169],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[8,0,0,169],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[8,0,0,170],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[7,0,0,170],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[8,0,0,171],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[7,0,0,171],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[8,0,0,172],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[7,0,0,172],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[8,0,0,173],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[7,0,0,173],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[8,0,0,174],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[7,0,0,174],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[7,0,0,175],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[8,0,0,175],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[8,0,0,176],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[7,0,0,176],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[8,0,0,177],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[7,0,0,177],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[7,0,0,178],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[8,0,0,178],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[8,0,0,179],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[7,0,0,179],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[8,0,0,180],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[7,0,0,180],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[8,0,0,181],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[7,0,0,181],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[8,0,0,182],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[7,0,0,182],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[8,0,0,183],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[7,0,0,183],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[8,0,0,184],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[7,0,0,184],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[8,0,0,185],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[7,0,0,185],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[7,0,0,186],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[8,0,0,186],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[7,0,0,187],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[8,0,0,187],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[7,0,0,188],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[8,0,0,188],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[7,0,0,189],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[8,0,0,189],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[7,0,0,190],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[8,0,0,190],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[7,0,0,191],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[8,0,0,191],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[8,0,0,192],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[7,0,0,192],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[8,0,0,193],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[7,0,0,193],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[8,0,0,194],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[7,0,0,194],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[7,0,0,195],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[8,0,0,195],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[7,0,0,196],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[8,0,0,196],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[8,0,0,197],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[7,0,0,197],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[8,0,0,198],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[7,0,0,198],
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[8,0,0,199]
};
